@@ -1,8 +1,7 @@
-# ABSTRACT: Vim::Debug Perl interface.
+# ABSTRACT: Perl debugger interface.
+
+
 package Vim::Debug::Perl;
-BEGIN {
-  $Vim::Debug::Perl::VERSION = '0.6';
-}
 
 use strict;
 use warnings;
@@ -13,13 +12,27 @@ $ENV{"PERL5DB"}     = 'BEGIN {require "perl5db.pl";}';
 $ENV{"PERLDB_OPTS"} = "ornaments=''";
 
 
-# used to parse debugger 
+
+
 our $dpr = '.*  DB<+\d+>+ '; # debugger prompt regex
 sub dbgrPromptRegex    { qr/$dpr/ }
 sub compilerErrorRegex { qr/aborted due to compilation error${dpr}/ }
 sub runtimeErrorRegex  { qr/ at .* line \d+${dpr}/ }
 sub appExitedRegex     { qr/((\/perl5db.pl:)|(Use .* to quit or .* to restart)|(\' to quit or \`R\' to restart))${dpr}/ }
 
+
+sub next                { return [ 'n'                  ] }
+sub step                { return [ 's'                  ] }
+sub cont                { return [ 'c'                  ] }
+sub break               { return [ "f $_[2]", "b $_[1]" ] }
+sub clear               { return [ "f $_[2]", "B $_[1]" ] }
+sub clearAll            { return [ "B *"                ] }
+sub print               { return [ "x $_[1]"            ] }
+sub command             { return [ $_[1]                ] }
+sub restart             { return [ "R"                  ] }
+sub quit                { return [ "q"                  ] }
+
+
 sub parseOutput {
    my $self   = shift or confess;
    my $output = shift or confess;
@@ -52,18 +65,6 @@ sub parseOutput {
    return undef;
 }
 
-sub next                { return [ 'n'                  ] }
-sub step                { return [ 's'                  ] }
-sub cont                { return [ 'c'                  ] }
-sub break               { return [ "f $_[2]", "b $_[1]" ] }
-sub clear               { return [ "f $_[2]", "B $_[1]" ] }
-sub clearAll            { return [ "B *"                ] }
-sub print               { return [ "x $_[1]"            ] }
-sub command             { return [ $_[1]                ] }
-sub restart             { return [ "R"                  ] }
-sub quit                { return [ "q"                  ] }
-
-
 1;
 
 __END__
@@ -71,11 +72,76 @@ __END__
 
 =head1 NAME
 
-Vim::Debug::Perl - Vim::Debug Perl interface.
+Vim::Debug::Perl - Perl debugger interface.
 
 =head1 VERSION
 
-version 0.6
+version 0.7
+
+=head1 SYNOPSIS
+
+If you are new to the Vim::Debug project please read the L<Vim::Debug::Manual> first.
+
+    package Vim::Debug::Perl
+
+    my $debugger = Vim::Debug::Perl->new;
+    $debugger->next;
+    $debugger->step;
+
+=head1 DESCRIPTION
+
+This module inherits from Vim::Debug.  See that module for a more in depth
+explanation.  This module only handles the Perl specific bits.
+
+=head1 DEBUGGER OUTPUT REGEX CLASS ATTRIBUTES
+
+These attributes are used to parse debugger output and are used by Vim::Debug.
+They return a regex and ignore all values passed to them.  
+
+=head2 dbgrPromptRegex()
+
+=head2 compilerErrorRegex()
+
+=head2 runtimeErrorRegex()
+
+=head2 appExitedRegex()
+
+=head1 TRANSLATION CLASS ATTRIBUTES
+
+These attributes are used by Vim::Debug::Daemon to convert commands from the
+communication protocol to commands the Perl debugger can recognize.  For
+example, the communication protocol uses the keyword 'next' while the Perl
+debugger uses 'n'.
+
+=head2 next()
+
+=head2 step()
+
+=head2 cont()
+
+=head2 break()
+
+=head2 clear()
+
+=head2 clearAll()
+
+=head2 print()
+
+=head2 command()
+
+=head2 restart()
+
+=head2 quit()
+
+=head2 METHODS
+
+=head2 parseOutput($output)
+
+$output is output from the Perl debugger.  This method parses $output and
+saves relevant valus to the lineNumber, filePath, and output attributes (these
+attributes are defined in Vim::Debug)
+
+Returns undef.
 
 =head1 AUTHOR
 
